@@ -342,6 +342,10 @@ class RunConfigurationProvider:
         huml_env = Environment("huml-pipeline-env")
         huml_env.python.user_managed_dependencies = False # Let Azure ML manage dependencies
         huml_env.docker.enabled = True # Use a docker container
+        # Set Docker base image to the default CPU-based image
+        DOCKER_ARGUMENTS = ["--gpus", "all"]
+        huml_env.docker.arguments = DOCKER_ARGUMENTS
+        huml_env.docker.base_image = "mcr.microsoft.com/azureml/onnxruntime:latest-cuda"
 
         # Add the dependencies to the environment
         huml_env.python.conda_dependencies = packages
